kgdboc_earlycon_init() uses the console_lock to ensure that no consoles
are unregistered until the kgdboc_earlycon is setup. The console_list_lock
should be used instead because list synchronization responsibility will
be removed from the console_lock in a later change.

Signed-off-by: John Ogness <john.ogn...@linutronix.de>
---
 drivers/tty/serial/kgdboc.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/tty/serial/kgdboc.c b/drivers/tty/serial/kgdboc.c
index 8c2b7ccdfebf..a3ed9b34e2ab 100644
--- a/drivers/tty/serial/kgdboc.c
+++ b/drivers/tty/serial/kgdboc.c
@@ -558,13 +558,13 @@ static int __init kgdboc_earlycon_init(char *opt)
         */
 
        /*
         * Hold the console_lock to guarantee that no consoles are
         * unregistered until the kgdboc_earlycon setup is complete.
         * Trapping the exit() callback relies on exit() not being
         * called until the trap is setup. This also allows safe
         * traversal of the console list and race-free reading of @flags.
         */
-       console_lock();
+       console_list_lock();
        for_each_console(con) {
                if (con->write && con->read &&
                    (con->flags & (CON_BOOT | CON_ENABLED)) &&
@@ -606,7 +606,7 @@ static int __init kgdboc_earlycon_init(char *opt)
        }
 
 unlock:
-       console_unlock();
+       console_list_unlock();
 
        /* Non-zero means malformed option so we always return zero */
        return 0;
@@ -558,13 +558,13 @@ static int __init kgdboc_earlycon_init(char *opt)
 
        /*
-        * Hold the console_lock to guarantee that no consoles are
+        * Hold the console_list_lock to guarantee that no consoles are
         * unregistered until the kgdboc_earlycon setup is complete.
         * Trapping the exit() callback relies on exit() not being
-- 
2.30.2



_______________________________________________
Kgdb-bugreport mailing list
Kgdb-bugreport@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/kgdb-bugreport

Reply via email to